@@ -8,7 +8,7 @@ chatid = input()
 bot = Telegram(token)
 bot.send_message(chatid, 'Hello, World!')
 
-response = bot.getMe()
+response = bot.get_me()
 
 bot.start_polling()
 
